aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNick Clifton <nickc@cygnus.com>1998-10-01 10:52:36 +0000
committerNick Clifton <nickc@gcc.gnu.org>1998-10-01 10:52:36 +0000
commita09a009c459a7314cef619c329c9291a59fdb077 (patch)
treea0a48c15ec22cbd1c0d7be1f9f7615d0502fdff4
parente2af664c2d6add614f1ef044f78b0c6ef89cf0d7 (diff)
downloadgcc-a09a009c459a7314cef619c329c9291a59fdb077.zip
gcc-a09a009c459a7314cef619c329c9291a59fdb077.tar.gz
gcc-a09a009c459a7314cef619c329c9291a59fdb077.tar.bz2
Replace occurances of HANDLE_SYSV_PRAGMA with HANDLE_GENERIC_PRAGMAS.
From-SVN: r22711
-rw-r--r--gcc/cp/ChangeLog3
-rw-r--r--gcc/cp/lex.c25
-rw-r--r--gcc/f/ChangeLog5
-rw-r--r--gcc/f/lex.c6
4 files changed, 24 insertions, 15 deletions
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index 61c67f1..8f358d8 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -5,6 +5,9 @@ Thu Oct 1 10:43:45 1998 Nick Clifton <nickc@cygnus.com>
(start_function): Add invocation of
SET_DEFAULT_DECL_ATTRIBUTES, if defined.
+ * lex.c: Replace occurances of HANDLE_SYSV_PRAGMA with
+ HANDLE_GENERIC_PRAGMAS.
+
1998-09-28 Anthony Green <green@cygnus.com>
* semantics.c (finish_asm_stmt): Always permit volatile asms.
diff --git a/gcc/f/ChangeLog b/gcc/f/ChangeLog
index 0745a23..2560e3f 100644
--- a/gcc/f/ChangeLog
+++ b/gcc/f/ChangeLog
@@ -1,3 +1,8 @@
+Thu Oct 1 10:43:45 1998 Nick Clifton <nickc@cygnus.com>
+
+ * lex.c: Replace occurances of HANDLE_SYSV_PRAGMA with
+ HANDLE_GENERIC_PRAGMAS.
+
Mon Sep 28 04:22:00 1998 Jeffrey A Law (law@cygnus.com)
* news.texi: Update from Craig.
diff --git a/gcc/f/lex.c b/gcc/f/lex.c
index 2ccdc07..c43aa7e 100644
--- a/gcc/f/lex.c
+++ b/gcc/f/lex.c
@@ -1145,10 +1145,10 @@ ffelex_hash_ (FILE *finput)
if (HANDLE_PRAGMA (pragma_getc, pragma_ungetc, buffer))
goto skipline;
#endif /* HANDLE_PRAGMA */
-#ifdef HANDLE_SYSV_PRAGMA
- if (handle_sysv_pragma (buffer))
+#ifdef HANDLE_GENERIC_PRAGMAS
+ if (handle_generic_pragma (buffer))
goto skipline;
-#endif /* !HANDLE_SYSV_PRAGMA */
+#endif /* !HANDLE_GENERIC_PRAGMAS */
/* Issue a warning message if we have been asked to do so.
Ignoring unknown pragmas in system header file unless
diff --git a/gcc/cp/lex.c b/gcc/cp/lex.c
index 20e4700..ac4d8b49 100644
--- a/gcc/cp/lex.c
+++ b/gcc/cp/lex.c
@@ -75,8 +75,8 @@ static void store_pending_inline PROTO((tree, struct pending_inline *));
static void reinit_parse_for_expr PROTO((struct obstack *));
static int *init_cpp_parse PROTO((void));
static int handle_cp_pragma PROTO((char *));
-#ifdef HANDLE_SYSV_PRAGMA
-static int handle_sysv_pragma PROTO((int));
+#ifdef HANDLE_GENERIC_PRAGMAS
+static int handle_generic_pragma PROTO((int));
#endif
#ifdef GATHER_STATISTICS
#ifdef REDUCE_LENGTH
@@ -2308,7 +2308,7 @@ check_newline ()
goto skipline;
#ifdef HANDLE_PRAGMA
/* We invoke HANDLE_PRAGMA before HANDLE_SYSV_PRAGMA
(if both are defined), in order to give the back
end a chance to override the interpretation of
SYSV style pragmas. */
@@ -2317,10 +2317,10 @@ check_newline ()
goto skipline;
#endif /* HANDLE_PRAGMA */
-#ifdef HANDLE_SYSV_PRAGMA
- if (handle_sysv_pragma (token))
+#ifdef HANDLE_GENERIC_PRAGMAS
+ if (handle_generic_pragma (token))
goto skipline;
-#endif /* !HANDLE_SYSV_PRAGMA */
+#endif /* HANDLE_GENERIC_PRAGMAS */
/* Issue a warning message if we have been asked to do so.
Ignoring unknown pragmas in system header file unless
@@ -4934,17 +4934,17 @@ handle_cp_pragma (pname)
return 0;
}
-#ifdef HANDLE_SYSV_PRAGMA
+#ifdef HANDLE_GENERIC_PRAGMAS
-/* Handle a #pragma directive. INPUT is the current input stream,
- and C is a character to reread. Processes the entire input line
- and returns a character for the caller to reread: either \n or EOF. */
+/* Handle a #pragma directive. TOKEN is the type of the word following
+ the #pragma directive on the line. Process the entire input line and
+ return non-zero iff the directive successfully parsed. */
/* This function has to be in this file, in order to get at
the token types. */
static int
-handle_sysv_pragma (token)
+handle_generic_pragma (token)
register int token;
{
for (;;)
@@ -4977,7 +4977,8 @@ handle_sysv_pragma (token)
default:
return handle_pragma_token (NULL_PTR, NULL_TREE);
}
+
token = real_yylex ();
}
}
-#endif /* HANDLE_SYSV_PRAGMA */
+#endif /* HANDLE_GENERIC_PRAGMAS */
@@ -2308,7 +2308,7 @@ check_newline ()
goto skipline;
#ifdef HANDLE_PRAGMA
- /* We invoke HANDLE_PRAGMA before HANDLE_SYSV_PRAGMA
+ /* We invoke HANDLE_PRAGMA before HANDLE_GENERIC_PRAGMAS
(if both are defined), in order to give the back
end a chance to override the interpretation of